==> v6.0-preview1.tar.gz: ilspy/ICSharpCode.Decompiler/IL/Instructions/StringToInt.cs <==
﻿// Copyright (c) 2017 Siegfried Pammer
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of this
// software and associated documentation files (the "Software"), to deal in the Software
// without restriction, including without limitation the rights to use, copy, modify, merge,
// publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
// to whom the Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in all copies or
// substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
// INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
// FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.


using System.Collections.Generic;

namespace ICSharpCode.Decompiler.IL
{
	partial class StringToInt
	{
		public List<(string Key, int Value)> Map { get; }

		public StringToInt(ILInstruction argument, List<(string Key, int Value)> map)
			: base(OpCode.StringToInt)
		{
			this.Argument = argument;
			this.Map = map;
		}

		public StringToInt(ILInstruction argument, string[] map)
			: this(argument, ArrayToDictionary(map))
		{
		}

		static List<(string Key, int Value)> ArrayToDictionary(string[] map)
		{
			var dict = new List<(string Key, int Value)>();
			for (int i = 0; i < map.Length; i++) {
				dict.Add((map[i], i));
			}
			return dict;
		}

		public override void WriteTo(ITextOutput output, ILAstWritingOptions options)
		{
			WriteILRange(output, options);
			output.Write("string.to.int (");
			Argument.WriteTo(output, options);
			output.Write(", { ");
			int i = 0;
			foreach (var entry in Map) {
				if (i > 0) output.Write(", ");
				if (entry.Key is null)
					output.Write($"[null] = {entry.Value}");
				else
					output.Write($"[\"{entry.Key}\"] = {entry.Value}");
				i++;
			}
			output.Write(" })");
		}
	}
}

==> v6.2-preview1.tar.gz: ilspy/ICSharpCode.Decompiler/IL/Instructions/StringToInt.cs <==
﻿// Copyright (c) 2017 Siegfried Pammer
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of this
// software and associated documentation files (the "Software"), to deal in the Software
// without restriction, including without limitation the rights to use, copy, modify, merge,
// publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
// to whom the Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in all copies or
// substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
// INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
// FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.


using System.Collections.Generic;

namespace ICSharpCode.Decompiler.IL
{
	partial class StringToInt
	{
		public List<(string Key, int Value)> Map { get; }

		public StringToInt(ILInstruction argument, List<(string Key, int Value)> map)
			: base(OpCode.StringToInt)
		{
			this.Argument = argument;
			this.Map = map;
		}

		public StringToInt(ILInstruction argument, string[] map)
			: this(argument, ArrayToDictionary(map))
		{
		}

		static List<(string Key, int Value)> ArrayToDictionary(string[] map)
		{
			var dict = new List<(string Key, int Value)>();
			for (int i = 0; i < map.Length; i++)
			{
				dict.Add((map[i], i));
			}
			return dict;
		}

		public override void WriteTo(ITextOutput output, ILAstWritingOptions options)
		{
			WriteILRange(output, options);
			output.Write("string.to.int (");
			Argument.WriteTo(output, options);
			output.Write(", { ");
			int i = 0;
			foreach (var entry in Map)
			{
				if (i > 0)
					output.Write(", ");
				if (entry.Key is null)
					output.Write($"[null] = {entry.Value}");
				else
					output.Write($"[\"{entry.Key}\"] = {entry.Value}");
				i++;
			}
			output.Write(" })");
		}
	}
}
